@@ -356,13 +356,11 @@ void MainWindow::ApplySettings()
 
         if (m_PbCharge == NULL){
             m_PbCharge = new BatteryWidget(ui->frame);
-            m_PbCharge->SetBackgroundImage(QPixmap(":/images/battery.png"));
             m_PbCharge->SetNormalLevelImage(QPixmap(":/images/green.png"));
             m_PbCharge->SetLowLevelImage(QPixmap(":/images/orange.png"));
             m_PbCharge->SetCriticalLevelImage(QPixmap(":/images/red.png"));
             m_PbCharge->setFixedSize(166, 98);
-            m_PbCharge->SetRange(0, 10000);
-            m_PbCharge->SetInsideMargins(8, 8, 16, 8);
+            m_PbCharge->SetRange(0, 10000);            
             m_PbCharge->SetLevels(50, 30);
             m_PbCharge->SetValue(0);
             ui->frame->layout()->addWidget(m_PbCharge);
@@ -376,7 +374,10 @@ void MainWindow::ApplySettings()
     }
 
     if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleGraphical){
+        m_PbCharge->SetBackgroundImage(QPixmap(":/images/battery.png"));
         m_PbCharge->setFixedHeight(QWIDGETSIZE_MAX);
+        m_PbCharge->SetInsideMargins(8, 8, 16, 8);
+
         QSize bkgSize(166, 98);
         bkgSize.scale(166*CommonStatic::CurrentSettings->PercScale, 98*CommonStatic::CurrentSettings->PercScale, Qt::KeepAspectRatio);
 
@@ -388,7 +389,10 @@ void MainWindow::ApplySettings()
         m_PbCharge->setFixedSize(bkgSize);
         m_PbCharge->SetInsideMargins(8*CommonStatic::CurrentSettings->PercScale, 8*CommonStatic::CurrentSettings->PercScale, 16*CommonStatic::CurrentSettings->PercScale, 8*CommonStatic::CurrentSettings->PercScale);
     }else if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleStandard){
-        m_PbCharge->setFixedHeight(48);
+        m_PbCharge->SetBackgroundImage(QPixmap(":/images/grey.png"));
+        m_PbCharge->setFixedSize(QWIDGETSIZE_MAX, 48);
+        m_PbCharge->SetInsideMargins(0, 0, 0, 0);
+
         ui->lblPerc->setVisible(false);
         ui->frame->setVisible(true);
         ui->frame->setFixedSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
